@@ -1,7 +1,7 @@
 package Perinci::Access::Schemeless;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.85'; # VERSION
+our $DATE = '2016-02-04'; # DATE
+our $VERSION = '0.86'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,7 +22,7 @@ use Tie::Cache;
 use URI::Split qw(uri_split uri_join);
 
 our $re_perl_package =
-    qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_][A-Za-z_0-9]*)*\z/;
+    qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9][A-Za-z_0-9]*)*\z/;
 
 sub new {
     require Class::Inspector;
@@ -1037,7 +1037,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.85 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-12-17.
+This document describes version 0.86 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2016-02-04.
 
 =head1 DESCRIPTION
 
@@ -1138,6 +1138,15 @@ if the C<load> attribute is set to true.
 
 =for Pod::Coverage ^(actionmeta_.+|action_.+|get_(meta|code))$
 
+=head1 ADDED RESULT METADATA
+
+This class might add the following property/attribute in result metadata:
+
+=head2 x.hint.result_binary => bool
+
+If result's schema type is C<buf>, then this class will set this attribute to
+true, to give hints to result formatters.
+
 =head1 METHODS
 
 =head2 PKG->new(%attrs) => OBJ
@@ -1241,19 +1250,6 @@ the Riap request key 'uri', as there is no server in this case.
 
 =head2 $pa->parse_url($server_url) => HASH
 
-=head1 ADDED RESULT METADATA
-
-This class might add the following property/attribute in result metadata:
-
-=head2 x.hint.result_binary => bool
-
-If result's schema type is C<buf>, then this class will set this attribute to
-true, to give hints to result formatters.
-
-=head1 SEE ALSO
-
-L<Riap>, L<Rinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Access-Perl>.
@@ -1270,13 +1266,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Riap>, L<Rinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
